#
# File:    ./src/vutils/yaml/version.py
# Author:  Jiří Kučera <sanczes AT gmail.com>
# Date:    2022-06-23 10:01:39 +0200
# Project: vutils-yaml: Working with YAML format
#
# SPDX-License-Identifier: MIT
#
"""
Holds :mod:`vutils.yaml` version.

:const __version__: The package version
"""

__version__: str = "0.1.4"



#
# File:    ./tests/unit/utils.py
# Author:  Jiří Kučera <sanczes AT gmail.com>
# Date:    2022-07-07 18:20:52 +0200
# Project: vutils-yaml: Working with YAML format
#
# SPDX-License-Identifier: MIT
#
"""
Unit tests utilities.

:const SLOT: The auxiliary slot name
:const VALUE: The auxiliary value
"""

SLOT = "__foo__"
VALUE = "bar:42"
